@@ -104,7 +104,7 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
             total_w = np.sum(list_v)
             list_total_w.append(str(round(total_w, 4)))
 
-        print(field + "\t" + ','.join(top_keywords) + "\t" + str(round(total_w, 4)) + "\t" + "\t".join(list_total_w))
+        print(field + "\t" + ','.join(top_keywords) + "\t"  + "\t".join(list_total_w))
     # ##################################KInteraction#########################################
     def get_common_words(ks1, ks2, vs1, vs2):
         list_common_words = []
