@@ -11,7 +11,9 @@ def run_topic_interaction(meta_csv_file,raw_text_folder, output_folder,list_cate
                           prefix_filename="",
                           num_topics=6,
                           num_pass=10,
-                          num_words=50
+                          num_words=50,
+                          lang='zh',
+                          minimum_num_doc_in_lda=15
                           ):
     # step 1
     divide_by_tag(
@@ -36,7 +38,9 @@ def run_topic_interaction(meta_csv_file,raw_text_folder, output_folder,list_cate
         stopwords_path=stopwords_path,
         num_topics=num_topics,
         num_pass=num_pass,
-        num_words=num_words
+        num_words=num_words,
+        lang=lang,
+        minimum_num_doc=minimum_num_doc_in_lda
     )
     # step 3
 
