@@ -4,8 +4,9 @@ import jieba
 import jieba.posseg as pseg
 from quickcsv.file import *
 import os
+from quick_topic.topic_interaction.lda_by_tag_each import *
 
-def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file=None,stopwords_path="",save_name="topic",output_folder="output"):
+def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file=None,stopwords_path="",save_name="topic",output_folder="output",lang='zh'):
 
     # ============ begin configure ====================
     NUM_TOPICS = num_topics
@@ -31,30 +32,13 @@ def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file
     # compile sample documents into a list
     # doc_set = [doc_a, doc_b, doc_c, doc_d, doc_e]
 
-    doc_set = []
-    for doc in list_doc:
-        # list_words=jieba.cut(doc,cut_all=False)
-        list_words = pseg.cut(doc)
-        list_w = []
-        for w, f in list_words:
-            if f in ['n', 'nr', 'ns', 'nt', 'nz', 'vn', 'nd', 'nh', 'nl', 'i']:
-                if w not in stopwords and len(w) != 1:
-                    list_w.append(w)
-        # print(list_w)
-        doc_set.append(list_w)
-
-    # list for tokenized documents in loop
-    texts = []
-
-    # loop through document list
-    for tokens in doc_set:
-        # clean and tokenize document string
-
-        # stem tokens
-        # stemmed_tokens = [p_stemmer.stem(i) for i in tokens]
-
-        # add tokens to list
-        texts.append(tokens)
+    texts = None
+    if lang == 'zh':
+        for pp in list_term_file:
+            jieba.load_userdict(pp)
+        texts = get_text_chinese(list_doc, stopwords_path=stopwords_path)
+    else:
+        texts = get_text_english(list_doc)
 
     # turn our tokenized documents into a id <-> term dictionary
     dictionary = corpora.Dictionary(texts)
@@ -104,6 +88,7 @@ def build_lda_models(meta_csv_file,raw_text_folder,tag_field="area",id_field="fi
                      prefix_filename="text_",list_term_file=None,stopwords_path="",
                      output_folder="results/topic_modeling",
                     num_topics=6,num_words=50,num_pass=5,
+                     lang='zh'
                      ):
 
     #meta_csv_file = "datasets/list_country.csv"
@@ -137,7 +122,8 @@ def build_lda_models(meta_csv_file,raw_text_folder,tag_field="area",id_field="fi
             list_term_file=list_term_file,
             num_pass=num_pass,
             num_topics=num_topics,
-            num_words=num_words
+            num_words=num_words,
+            lang=lang
         )
     return list(dict_country.keys())
 
