@@ -8,8 +8,9 @@ def run_topic_prevalence(meta_csv_file,raw_text_folder,save_root_folder, list_ke
     id_field="Id",
     prefix_filename="",
     num_topics=6,
-                         num_words=50,
-                         num_pass=5
+    num_words=50,
+    num_pass=5,
+    lang='zh'
                          ):
     # step 1
     if not os.path.exists(save_root_folder):
@@ -30,7 +31,8 @@ def run_topic_prevalence(meta_csv_file,raw_text_folder,save_root_folder, list_ke
                     stopwords_path=stop_words_path,
                     num_topics=num_topics,
                     num_words=num_words,
-                    num_pass=num_pass
+                    num_pass=num_pass,
+                lang=lang
                     )
 
     # step 3
