@@ -20,6 +20,8 @@ def divide_by_year_month(meta_csv_file,raw_text_folder,output_folder,tag_field="
         if '-' in pubtime:
             year=pubtime.split("-")[0]
             month=pubtime.split("-")[1]
+            if len(month)==1:
+                month="0"+month
             year_month=f"{year}-{month}"
         if year_month.strip()=="":
             continue
